==> eam-wshub-proxyclient-11.5-10-sources.jar: net/datastream/schemas/mp_fields/USERDEFINEDFIELDINFO.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRINT" minOccurs="0"/>
 *         &lt;element name="MAXVALUE" type="{http://schemas.datastream.net/MP_fields}CODE80_Type" minOccurs="0"/>
 *         &lt;element name="MINVALUE" type="{http://schemas.datastream.net/MP_fields}CODE80_Type" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDFIELDLOVSETTINGS" minOccurs="0"/>
 *         &lt;element name="DATETYPE" type="{http://schemas.datastream.net/MP_fields}CODE4_Type" minOccurs="0"/>
 *         &lt;element name="NUMTYPE" type="{http://schemas.datastream.net/MP_fields}CODE4_Type" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CURRENCYCODE" minOccurs="0"/>
 *         &lt;element name="ENABLEFORADDONS" type="{http://schemas.datastream.net/MP_fields}FLAG_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "entityid",
    "print",
    "maxvalue",
    "minvalue",
    "uomcode",
    "userdefinedfieldlovsettings",
    "datetype",
    "numtype",
    "currencycode",
    "enableforaddons"
})
@XmlRootElement(name = "USERDEFINEDFIELDINFO")
public class USERDEFINEDFIELDINFO {

    @XmlElement(name = "ENTITYID", required = true)
    protected ENTITYID_Type entityid;
    @XmlElement(name = "PRINT")
    protected String print;
    @XmlElement(name = "MAXVALUE")
    protected String maxvalue;
    @XmlElement(name = "MINVALUE")
    protected String minvalue;
    @XmlElement(name = "UOMCODE")
    protected String uomcode;
    @XmlElement(name = "USERDEFINEDFIELDLOVSETTINGS")
    protected USERDEFINEDFIELDLOVSETTINGS userdefinedfieldlovsettings;
    @XmlElement(name = "DATETYPE")
    protected String datetype;
    @XmlElement(name = "NUMTYPE")
    protected String numtype;
    @XmlElement(name = "CURRENCYCODE")
    protected String currencycode;
    @XmlElement(name = "ENABLEFORADDONS", required = true)
    protected String enableforaddons;

    /**
     * Obtient la valeur de la propriété entityid.
     * 
     * @return
     *     possible object is
     *     {@link ENTITYID_Type }
     *     
     */
    public ENTITYID_Type getENTITYID() {
        return entityid;
    }

    /**
     * Définit la valeur de la propriété entityid.
     * 
     * @param value
     *     allowed object is
     *     {@link ENTITYID_Type }
     *     
     */
    public void setENTITYID(ENTITYID_Type value) {
        this.entityid = value;
    }

    /**
     * Obtient la valeur de la propriété print.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRINT() {
        return print;
    }

    /**
     * Définit la valeur de la propriété print.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRINT(String value) {
        this.print = value;
    }

    /**
     * Obtient la valeur de la propriété maxvalue.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMAXVALUE() {
        return maxvalue;
    }

    /**
     * Définit la valeur de la propriété maxvalue.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMAXVALUE(String value) {
        this.maxvalue = value;
    }

    /**
     * Obtient la valeur de la propriété minvalue.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMINVALUE() {
        return minvalue;
    }

    /**
     * Définit la valeur de la propriété minvalue.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMINVALUE(String value) {
        this.minvalue = value;
    }

    /**
     * Obtient la valeur de la propriété uomcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUOMCODE() {
        return uomcode;
    }

    /**
     * Définit la valeur de la propriété uomcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUOMCODE(String value) {
        this.uomcode = value;
    }

    /**
     * Obtient la valeur de la propriété userdefinedfieldlovsettings.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDFIELDLOVSETTINGS }
     *     
     */
    public USERDEFINEDFIELDLOVSETTINGS getUSERDEFINEDFIELDLOVSETTINGS() {
        return userdefinedfieldlovsettings;
    }

    /**
     * Définit la valeur de la propriété userdefinedfieldlovsettings.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDFIELDLOVSETTINGS }
     *     
     */
    public void setUSERDEFINEDFIELDLOVSETTINGS(USERDEFINEDFIELDLOVSETTINGS value) {
        this.userdefinedfieldlovsettings = value;
    }

    /**
     * Obtient la valeur de la propriété datetype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDATETYPE() {
        return datetype;
    }

    /**
     * Définit la valeur de la propriété datetype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDATETYPE(String value) {
        this.datetype = value;
    }

    /**
     * Obtient la valeur de la propriété numtype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNUMTYPE() {
        return numtype;
    }

    /**
     * Définit la valeur de la propriété numtype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNUMTYPE(String value) {
        this.numtype = value;
    }

    /**
     * Obtient la valeur de la propriété currencycode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCURRENCYCODE() {
        return currencycode;
    }

    /**
     * Définit la valeur de la propriété currencycode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCURRENCYCODE(String value) {
        this.currencycode = value;
    }

    /**
     * Obtient la valeur de la propriété enableforaddons.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENABLEFORADDONS() {
        return enableforaddons;
    }

    /**
     * Définit la valeur de la propriété enableforaddons.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENABLEFORADDONS(String value) {
        this.enableforaddons = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/USERDEFINEDFIELDINFO.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRINT" minOccurs="0"/>
 *         &lt;element name="MAXVALUE" type="{http://schemas.datastream.net/MP_fields}CODE80_Type" minOccurs="0"/>
 *         &lt;element name="MINVALUE" type="{http://schemas.datastream.net/MP_fields}CODE80_Type" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDFIELDLOVSETTINGS" minOccurs="0"/>
 *         &lt;element name="DATETYPE" type="{http://schemas.datastream.net/MP_fields}CODE4_Type" minOccurs="0"/>
 *         &lt;element name="NUMTYPE" type="{http://schemas.datastream.net/MP_fields}CODE4_Type" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CURRENCYCODE" minOccurs="0"/>
 *         &lt;element name="ENABLEFORADDONS" type="{http://schemas.datastream.net/MP_fields}FLAG_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "entityid",
    "print",
    "maxvalue",
    "minvalue",
    "uomcode",
    "userdefinedfieldlovsettings",
    "datetype",
    "numtype",
    "currencycode",
    "enableforaddons"
})
@XmlRootElement(name = "USERDEFINEDFIELDINFO")
public class USERDEFINEDFIELDINFO {

    @XmlElement(name = "ENTITYID", required = true)
    protected ENTITYID_Type entityid;
    @XmlElement(name = "PRINT")
    protected String print;
    @XmlElement(name = "MAXVALUE")
    protected String maxvalue;
    @XmlElement(name = "MINVALUE")
    protected String minvalue;
    @XmlElement(name = "UOMCODE")
    protected String uomcode;
    @XmlElement(name = "USERDEFINEDFIELDLOVSETTINGS")
    protected USERDEFINEDFIELDLOVSETTINGS userdefinedfieldlovsettings;
    @XmlElement(name = "DATETYPE")
    protected String datetype;
    @XmlElement(name = "NUMTYPE")
    protected String numtype;
    @XmlElement(name = "CURRENCYCODE")
    protected String currencycode;
    @XmlElement(name = "ENABLEFORADDONS", required = true)
    protected String enableforaddons;

    /**
     * Gets the value of the entityid property.
     * 
     * @return
     *     possible object is
     *     {@link ENTITYID_Type }
     *     
     */
    public ENTITYID_Type getENTITYID() {
        return entityid;
    }

    /**
     * Sets the value of the entityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ENTITYID_Type }
     *     
     */
    public void setENTITYID(ENTITYID_Type value) {
        this.entityid = value;
    }

    /**
     * Gets the value of the print property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRINT() {
        return print;
    }

    /**
     * Sets the value of the print property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRINT(String value) {
        this.print = value;
    }

    /**
     * Gets the value of the maxvalue property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMAXVALUE() {
        return maxvalue;
    }

    /**
     * Sets the value of the maxvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMAXVALUE(String value) {
        this.maxvalue = value;
    }

    /**
     * Gets the value of the minvalue property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMINVALUE() {
        return minvalue;
    }

    /**
     * Sets the value of the minvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMINVALUE(String value) {
        this.minvalue = value;
    }

    /**
     * Gets the value of the uomcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUOMCODE() {
        return uomcode;
    }

    /**
     * Sets the value of the uomcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUOMCODE(String value) {
        this.uomcode = value;
    }

    /**
     * Gets the value of the userdefinedfieldlovsettings property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDFIELDLOVSETTINGS }
     *     
     */
    public USERDEFINEDFIELDLOVSETTINGS getUSERDEFINEDFIELDLOVSETTINGS() {
        return userdefinedfieldlovsettings;
    }

    /**
     * Sets the value of the userdefinedfieldlovsettings property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDFIELDLOVSETTINGS }
     *     
     */
    public void setUSERDEFINEDFIELDLOVSETTINGS(USERDEFINEDFIELDLOVSETTINGS value) {
        this.userdefinedfieldlovsettings = value;
    }

    /**
     * Gets the value of the datetype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDATETYPE() {
        return datetype;
    }

    /**
     * Sets the value of the datetype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDATETYPE(String value) {
        this.datetype = value;
    }

    /**
     * Gets the value of the numtype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNUMTYPE() {
        return numtype;
    }

    /**
     * Sets the value of the numtype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNUMTYPE(String value) {
        this.numtype = value;
    }

    /**
     * Gets the value of the currencycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCURRENCYCODE() {
        return currencycode;
    }

    /**
     * Sets the value of the currencycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCURRENCYCODE(String value) {
        this.currencycode = value;
    }

    /**
     * Gets the value of the enableforaddons property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENABLEFORADDONS() {
        return enableforaddons;
    }

    /**
     * Sets the value of the enableforaddons property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENABLEFORADDONS(String value) {
        this.enableforaddons = value;
    }

}
